==> rapid_widgets_library-0.2.33.tar.gz: lib/consts.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

// Path for images
const imagePath = "images/";
//Font Size
const double font_small = 16.0;
const double font_medium = 18.0;
//tabs
const double offset1 = 0.2;
const double offset2 = 0.2;
const double tab_underline_width = 2.0;
const double tab_border_width = 1.0;
const double tab_border = 50.0;

//buttons

const double button_heightElevation = 8.0;
const double button_elevation = 7.0;
const double button_disabledElevation = 10.0;
const text_button = "Okay";
const Icon icon_button = Icon(Icons.access_time);

const double buttonBorderRadius = 0.0;
const double button_edgeInsetsAll = 20.0;
const double button_height = 50.0;
const double button_borderWidth = 2.0;
const double button_width = 70.0;

const double font_larger = 20.0;
const int intOne = 1;
const int intTwo = 2;
const int intThree = 3;
const int intFive = 5;
const int intFiveHundred = 500;

// Default values for thickness, height of containers, borders  etc
const double heightTwentyPixel = 20;
const double thicknesssTwoPixel = 2;
const double indentOnePixel = 1;
const double endIndentOnePixel = 1;
const EdgeInsetsGeometry edgeInsetValues = EdgeInsets.all(20.0);
const double circular_radius = 10;

const listTitle = "Sample list title";
const listSubtitle = "Sample list subtitle";

const sampleText = "Sample Text";

// Default icons
const IconData icon1 = Icons.watch_later;
const IconData icon2 = Icons.warning;
const IconData icon_add = Icons.add_box;

// Progress indicators
const double intialValue = null;

const double fontSmall = 16.0;
const double fontMedium = 18.0;
const double fontLarger = 20.0;
const FontWeight fontBold = FontWeight.bold;
//SizedBox height/width
const double heightOne = 1.0;
const double heightTwo = 2.0;
const double heightThree = 3.0;
const double heightFive = 5.0;
const double heightTen = 10.0;
const double heightTwenty = 20.0;
const double heightTwentyFive = 25.0;
const double heightThirty = 30.0;
const double heightFourrty = 40.0;
const double heightFifty = 50.0;
const double heightSeventy = 70.0;
const double heightEighty = 80.0;
const double heightHundred = 100.0;
const double heightOneEighty = 180.0;
const double heightTwoHundred = 200.0;
const double heightThreeHundred = 300.0;
const double heightFourHundred = 400.0;
const double heightFiveHundred = 500.0;

// Default values for thickness, height of containers, borders  etc

//Default Values for Text
const snackBarButtonText = "Show Snackbar";
const snackBarContent = "Message goes here";
const snackBarLabel = "Undo";

const chipTooltipMessage = "Show Snackbar";
const chipDeleteMessage = "Message goes here";
const chipLabel = "Brand";
const noDataMsg = "No Records Found !";
const txtColOne = "Column One";
const txtColTwo = "Column Two";

const dialogHeader = "";
const dialogContent = "content";
const dialogButtonText = "Text";
const cancelButtonText = "Cancel";

const cardImagePath = imagePath + "card1.png";
const networkCardImagePath = "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcScmRgfk7h2Wr9Vhcr-1y6ILseP7Km08AIjSdHoNuLERkJg9f-x&usqp=CAU";
const cardTitle = "Card Title";
const cardSubtitle = "Card Subtitle";
const cardBtnText = "7.30 PM";
const MainAxisSize mainAxis_size = MainAxisSize.min;

const List DROPDOWNLIST = ['Option A', 'Option B', 'Option C'];
const optionA = 'Option A';
const optionB = 'Option B';
const optionC = 'Option C';
const optionD = 'Option D';

const double heightSixty = 60;
const double dropDown_width = 300;
const FontWeight bold = FontWeight.bold;
const double image_width = 90;
const double blur_radius = 0;
const double spread_radius = 0;
const double shadow_offsetx = 0;
const double shadow_offsety = 0;
const double icon_size = 24;
const double border_width = 2;
const ShapeBorder FloatingActionButtonShape = CircleBorder();
ShapeBorder outlineButtonShape = RoundedRectangleBorder(borderRadius: new BorderRadius.circular(heightThirty));
const int five = 5;
const int start_year = 2000;
const int start_month = 1;
const int one = 1;
const int end_year = 2080;
const int end_month = 1;
const int initial_year = 2020;
const int initial_month = 1;
const int zero = 0;

const int two = 2;
const int three = 3;
const double threshold1 = 0.1;
const int oneSecond = 1000;
const double doubleOne = 1.0;
const double pointEight = 0.8;
const double doubleTwo = 2.0;
const double doubleZero = 0.0;
const double pointThree = 0.3;
const fontFamily = 'Roboto';
const buttonLabel = "Submit";
const Drawer_username = 'Username';
const Drawer_email = 'abc@xyz.com';

const assetImage = "images/logo.png";
const Network = 'Network';
const Asset = 'Asset';
const network = 'network';
const asset = 'asset';
const String = 'String';
//const NetworkImage = 'NetworkImage';
const AsseImage = 'AssetImage';
const text1 = 'This is text1';
const text2 = 'This is text2';
const text3 = 'This is text3';
const text4 = 'This is text4';
const networkImage1 = 'https://picsum.photos/250?image=9';
const networkImage2 = 'https://i.picsum.photos/id/1018/3914/2935.jpg?hmac=3N43cQcvTE8NItexePvXvYBrAoGbRssNMpuvuWlwMKg';
const networkImage3 = 'https://i.picsum.photos/id/1005/5760/3840.jpg?hmac=2acSJCOwz9q_dKtDZdSB-OIK1HUcwBeXco_RMMTUgfY';
Widget drawerIcon1 = Icon(Icons.account_circle);
Widget drawerIcon2 = Icon(Icons.history);
Widget drawerIcon3 = Icon(Icons.account_balance_wallet);
Widget drawerIcon4 = Icon(Icons.cancel);
Widget drawerText1 = Text("Account details");
Widget drawerText2 = Text("Order History");
Widget drawerText3 = Text("Wallet");
Widget drawerText4 = Text("Logout");
const userName = 'Account Name';
const userEmail = 'abc@xyz.com';
CarouselList prodObj1 = new CarouselList(
    widget: Icon(
  Icons.person,
  size: 50,
));
CarouselList prodObj2 = new CarouselList(
    widget: Icon(
  Icons.cloud,
  size: 50,
));
CarouselList prodObj3 = new CarouselList(
    widget: Image.asset(
  'images/logo.png',
  height: 100,
));
CarouselList prodObj4 = new CarouselList(widget: Container(color: Colors.red, height: 50, width: 50));
CarouselList prodObj5 = new CarouselList(widget: Container(color: Colors.yellow, height: 100, width: 80));
CarouselList prodObj6 = new CarouselList(
    widget: Image.asset(
  'images/logo.png',
  height: 100,
));
CarouselList prodObj7 = new CarouselList(widget: Container(color: Colors.orange, height: 50, width: 50));

List<CarouselList> defaultCarouselList = [prodObj1, prodObj2, prodObj3, prodObj4, prodObj5, prodObj6, prodObj7];

const double linear_larger = 30.0;

// Constant general values based on coin
const double onePixelDouble = 1;
const double twoPixelDouble = 2;
const double fivePixelDouble = 5;
const double tenPixelDouble = 10;
const double twentyPixelDouble = 20;
const double fiftyPixelDouble = 50;
const double hundredPixelDouble = 100;

const int onePixelInt = 1;
const int twoPixelInt = 2;
const int fivePixelInt = 5;
const int tenPixelInt = 10;
const int twentyPixelInt = 20;
const int fiftyPixelInt = 50;
const int hundredPixelInt = 100;

//TextField
const int MAX_Length = 50;
const bool MAX_Length_Enforced = false;
const bool OBSECURE_Text = false;

//Slider
const int DIVS = 5;
const double MAX = 50.0;
const double MIN = 0.0;
const double value = 0.0;

//BottomSheet
const double MIN_HEIGHT = 75.0;
const double MAX_HEIGHT = 200.0;
const double icon_size1 = 25;
const double font_size1 = 16;
const double padding_value1 = 0;
const double padding_value2 = 0;

//Alert Dialog
const DIALOG_BUTTON_T1 = "Yes";
const DIALOG_BUTTON_T2 = "No";
const double font_size2 = 20;
const double height_factor1 = 0.60;
const double width_factor1 = 0.90;

//HorizontalCard
const double Container_Height = 300;
const double Tile_Height = 350;
const double Tile_Width = 350;

const double fontVeryLarge = 40.0;

//SizedBox height/width

const textStyle = 'Roboto';
int pieAnimationTime = 2;
int pieMaxRows = 2;

const listTop = "Top";
const listBottom = "Bottom";

const double bottomOpacity = 1.0;
const double tileSpacing = 1.0;
const double toolbarOpacity = 1.0;
const bool primary = true;
const double elevation = 5.0;
const bool automaticallyImplyLoading = true;
const bool excludeHeaderSemantics = true;
const double strokeWidthTwo = 2.0;
StrokeCap strokeCapRound = StrokeCap.round;

const LIST_LABEL = 'Select an option';

List<BottomNavigationBarItem> bottomNavBarDefault = [
  BottomNavigationBarItem(
    icon: Icon(Icons.home),
    label: 'Home',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.phone),
    label: 'Phone',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.assistant),
    label: 'Assisstant',
  ),
];

const Widget title = Text("AppBar");
const textAlign = TextAlign.center;
const bool centerTitle = true;
List<Widget> appBarIcons = [
  IconButton(
    icon: const Icon(Icons.home),
    onPressed: () {
      print("Home");
    },
  ),
  IconButton(
    icon: const Icon(Icons.settings),
    onPressed: () {
      print("Settings");
    },
  ),
  IconButton(
    icon: const Icon(Icons.arrow_back),
    onPressed: () {
      print("Back");
    },
  ),
];

const Offset offsetDefault = Offset(2.0, 2.0);

const callbackMessage = 'Please pass the values to the object of product class';

const carouselTitle1 = "Product Name";
const carouselTitle2 = "Product Type";
const carouselTitle3 = "Product Quantity";
const carouselTitle4 = "Product Price";
const signUpHeading = "Sign Up";
const appTitle = "VIC STARTUP";
const termsnConditions = 'By signing up you accept the Terms and Conditions.';
const successMsg = 'Your account has been created Successfully';
const cont = 'Continue';
const bool automaticallyImplyLeading = false;
const double bottomOpacityOne = 1.0;
const double tileSpacingOne = 1.0;
const double toolbarOpacityOne = 1.0;
const double elevationFive = 5.0;
const double expandedHeight = 1.0;
Widget flexibleSpaceBar = Text("");
const bool forceElevated = false;
Brightness brightness = Brightness.light;
const bool floating = false;
const bool pinned = false;
const bool snap = false;
const bool stretch = false;
const double selectedFontSize = 5.0;
const double unselectedFontSize = 5.0;
const int speedThousand = 1000;
const double opacity = 0.2;
const double opacityCard = 0.8;
const bool showselectedlabels = true;
const bool showUnselectedLabels = true;
const int maxLines = 3;
List<Widget> action = [
  IconButton(
    icon: Icon(Icons.arrow_back),
    onPressed: () {},
  )
];
List<BottomNavigationBarItem> item = [
  BottomNavigationBarItem(
    icon: Icon(Icons.home),
    label: 'Home',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.business),
    label: 'Business',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.school),
    label: 'School',
  ),
];
const double stretchTriggerOffset = 1.0;

const IconData IconButton1 = Icons.add_box;
const IconData cameraIcon = Icons.camera_alt;

//VerticalTabs
const int durationTwo = 2;
const int snackbarDuration = 5000;
const double elevationTwo = 2.0;
const double tweenValueBegin = 0.0;
const double tweenValueEnd = 1.0;

const actPicjpg = 'images/account_picture.jpg';

const scanImage = "Scan";
const cameraPermissionDenied = "Camera permission was denied";
const cameraBackPress = "You pressed the back button before scanning anything";

//container dimensions
const containerwidth = 150.0;
const containerheight = 100.0;
const maxwidth = 600.0;

//Other constants

const jpg = '.jpg';
const jpeg = '.jpeg';
const png = '.png';

==> rapid_widgets_library-0.2.38.tar.gz: lib/consts.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:charts_flutter/flutter.dart' as charts;

// Path for images
const imagePath = "images/";
//Font Size
const double font_small = 16.0;
const double font_medium = 18.0;
//tabs
const double offset1 = 0.2;
const double offset2 = 0.2;
const double tab_underline_width = 2.0;
const double tab_border_width = 1.0;
const double tab_border = 50.0;

//buttons

const double button_heightElevation = 8.0;
const double button_elevation = 7.0;
const double button_disabledElevation = 10.0;
const text_button = "Okay";
const Icon icon_button = Icon(Icons.access_time);

const double buttonBorderRadius = 0.0;
const double button_edgeInsetsAll = 20.0;
const double button_height = 50.0;
const double button_borderWidth = 2.0;
const double button_width = 70.0;

const double font_larger = 20.0;
const int intOne = 1;
const int intTwo = 2;
const int intThree = 3;
const int intFive = 5;
const int intFiveHundred = 500;

// Default values for thickness, height of containers, borders  etc
const double heightTwentyPixel = 20;
const double thicknesssTwoPixel = 2;
const double indentOnePixel = 1;
const double endIndentOnePixel = 1;
const EdgeInsetsGeometry edgeInsetValues = EdgeInsets.all(20.0);
const double circular_radius = 10;

const listTitle = "Sample list title";
const listSubtitle = "Sample list subtitle";

const sampleText = "Sample Text";

// Default icons
const IconData icon1 = Icons.watch_later;
const IconData icon2 = Icons.warning;
const IconData icon_add = Icons.add_box;

// Progress indicators
const double intialValue = null;

const double fontSmall = 16.0;
const double fontMedium = 18.0;
const double fontLarger = 20.0;
const FontWeight fontBold = FontWeight.bold;
//SizedBox height/width
const double heightOne = 1.0;
const double heightTwo = 2.0;
const double heightThree = 3.0;
const double heightFive = 5.0;
const double heightTen = 10.0;
const double heightTwenty = 20.0;
const double heightTwentyFive = 25.0;
const double heightThirty = 30.0;
const double heightFourrty = 40.0;
const double heightFifty = 50.0;
const double heightSeventy = 70.0;
const double heightEighty = 80.0;
const double heightHundred = 100.0;
const double heightOneEighty = 180.0;
const double heightTwoHundred = 200.0;
const double heightThreeHundred = 300.0;
const double heightFourHundred = 400.0;
const double heightFiveHundred = 500.0;

// Default values for thickness, height of containers, borders  etc

//Default Values for Text
const snackBarButtonText = "Show Snackbar";
const snackBarContent = "Message goes here";
const snackBarLabel = "Undo";

const chipTooltipMessage = "Show Snackbar";
const chipDeleteMessage = "Message goes here";
const chipLabel = "Brand";
const noDataMsg = "No Records Found !";
const txtColOne = "Column One";
const txtColTwo = "Column Two";

const dialogHeader = "";
const dialogContent = "content";
const dialogButtonText = "Text";
const cancelButtonText = "Cancel";

const cardImagePath = imagePath + "card1.png";
const networkCardImagePath =
    "https://encrypted-tbn0.gstatic.com/images?q=tbn%3AANd9GcScmRgfk7h2Wr9Vhcr-1y6ILseP7Km08AIjSdHoNuLERkJg9f-x&usqp=CAU";
const cardTitle = "Card Title";
const cardSubtitle = "Card Subtitle";
const cardBtnText = "7.30 PM";
const MainAxisSize mainAxis_size = MainAxisSize.min;

const List DROPDOWNLIST = ['Option A', 'Option B', 'Option C'];
const optionA = 'Option A';
const optionB = 'Option B';
const optionC = 'Option C';
const optionD = 'Option D';

const double heightSixty = 60;
const double dropDown_width = 300;
const FontWeight bold = FontWeight.bold;
const double image_width = 90;
const double blur_radius = 0;
const double spread_radius = 0;
const double shadow_offsetx = 0;
const double shadow_offsety = 0;
const double icon_size = 24;
const double border_width = 2;
const ShapeBorder FloatingActionButtonShape = CircleBorder();
ShapeBorder outlineButtonShape = RoundedRectangleBorder(
    borderRadius: new BorderRadius.circular(heightThirty));
const int five = 5;
const int start_year = 2000;
const int start_month = 1;
const int one = 1;
const int end_year = 2080;
const int end_month = 1;
const int initial_year = 2020;
const int initial_month = 1;
const int zero = 0;

const int two = 2;
const int three = 3;
const double threshold1 = 0.1;
const int oneSecond = 1000;
const double doubleOne = 1.0;
const double pointEight = 0.8;
const double doubleTwo = 2.0;
const double doubleZero = 0.0;
const double pointThree = 0.3;
const fontFamily = 'Roboto';
const buttonLabel = "Submit";
const Drawer_username = 'Username';
const Drawer_email = 'abc@xyz.com';

const assetImage = "images/logo.png";
const Network = 'Network';
const Asset = 'Asset';
const network = 'network';
const asset = 'asset';
const String = 'String';
//const NetworkImage = 'NetworkImage';
const AsseImage = 'AssetImage';
const text1 = 'This is text1';
const text2 = 'This is text2';
const text3 = 'This is text3';
const text4 = 'This is text4';
const networkImage1 = 'https://picsum.photos/250?image=9';
const networkImage2 =
    'https://i.picsum.photos/id/1018/3914/2935.jpg?hmac=3N43cQcvTE8NItexePvXvYBrAoGbRssNMpuvuWlwMKg';
const networkImage3 =
    'https://i.picsum.photos/id/1005/5760/3840.jpg?hmac=2acSJCOwz9q_dKtDZdSB-OIK1HUcwBeXco_RMMTUgfY';
Widget drawerIcon1 = Icon(Icons.account_circle);
Widget drawerIcon2 = Icon(Icons.history);
Widget drawerIcon3 = Icon(Icons.account_balance_wallet);
Widget drawerIcon4 = Icon(Icons.cancel);
Widget drawerText1 = Text("Account details");
Widget drawerText2 = Text("Order History");
Widget drawerText3 = Text("Wallet");
Widget drawerText4 = Text("Logout");
const userName = 'Account Name';
const userEmail = 'abc@xyz.com';
CarouselList prodObj1 = new CarouselList(
    widget: Icon(
  Icons.person,
  size: 50,
));
CarouselList prodObj2 = new CarouselList(
    widget: Icon(
  Icons.cloud,
  size: 50,
));
CarouselList prodObj3 = new CarouselList(
    widget: Image.asset(
  'images/logo.png',
  height: 100,
));
CarouselList prodObj4 = new CarouselList(
    widget: Container(color: Colors.red, height: 50, width: 50));
CarouselList prodObj5 = new CarouselList(
    widget: Container(color: Colors.yellow, height: 100, width: 80));
CarouselList prodObj6 = new CarouselList(
    widget: Image.asset(
  'images/logo.png',
  height: 100,
));
CarouselList prodObj7 = new CarouselList(
    widget: Container(color: Colors.orange, height: 50, width: 50));

List<CarouselList> defaultCarouselList = [
  prodObj1,
  prodObj2,
  prodObj3,
  prodObj4,
  prodObj5,
  prodObj6,
  prodObj7
];

const double linear_larger = 30.0;

// Constant general values based on coin
const double onePixelDouble = 1;
const double twoPixelDouble = 2;
const double fivePixelDouble = 5;
const double tenPixelDouble = 10;
const double twentyPixelDouble = 20;
const double fiftyPixelDouble = 50;
const double hundredPixelDouble = 100;

const int onePixelInt = 1;
const int twoPixelInt = 2;
const int fivePixelInt = 5;
const int tenPixelInt = 10;
const int twentyPixelInt = 20;
const int fiftyPixelInt = 50;
const int hundredPixelInt = 100;

//TextField
const int MAX_Length = 50;
const bool MAX_Length_Enforced = false;
const bool OBSECURE_Text = false;

//Slider
const int DIVS = 5;
const double MAX = 50.0;
const double MIN = 0.0;
const double value = 0.0;

//BottomSheet
const double MIN_HEIGHT = 75.0;
const double MAX_HEIGHT = 200.0;
const double icon_size1 = 25;
const double font_size1 = 16;
const double padding_value1 = 0;
const double padding_value2 = 0;

//Alert Dialog
const DIALOG_BUTTON_T1 = "Yes";
const DIALOG_BUTTON_T2 = "No";
const double font_size2 = 20;
const double height_factor1 = 0.60;
const double width_factor1 = 0.90;

//HorizontalCard
const double Container_Height = 300;
const double Tile_Height = 350;
const double Tile_Width = 350;

const double fontVeryLarge = 40.0;

//SizedBox height/width

const textStyle = 'Roboto';
int pieAnimationTime = 2;
int pieMaxRows = 2;

const listTop = "Top";
const listBottom = "Bottom";

const double bottomOpacity = 1.0;
const double tileSpacing = 1.0;
const double toolbarOpacity = 1.0;
const bool primary = true;
const double elevation = 5.0;
const bool automaticallyImplyLoading = true;
const bool excludeHeaderSemantics = true;
const double strokeWidthTwo = 2.0;
StrokeCap strokeCapRound = StrokeCap.round;

const LIST_LABEL = 'Select an option';

List<BottomNavigationBarItem> bottomNavBarDefault = [
  BottomNavigationBarItem(
    icon: Icon(Icons.home),
    label: 'Home',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.phone),
    label: 'Phone',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.assistant),
    label: 'Assisstant',
  ),
];

const Widget title = Text("AppBar");
const textAlign = TextAlign.center;
const bool centerTitle = true;
List<Widget> appBarIcons = [
  IconButton(
    icon: const Icon(Icons.home),
    onPressed: () {
      print("Home");
    },
  ),
  IconButton(
    icon: const Icon(Icons.settings),
    onPressed: () {
      print("Settings");
    },
  ),
  IconButton(
    icon: const Icon(Icons.arrow_back),
    onPressed: () {
      print("Back");
    },
  ),
];

const Offset offsetDefault = Offset(2.0, 2.0);

const callbackMessage = 'Please pass the values to the object of product class';

const carouselTitle1 = "Product Name";
const carouselTitle2 = "Product Type";
const carouselTitle3 = "Product Quantity";
const carouselTitle4 = "Product Price";
const signUpHeading = "Sign Up";
const appTitle = "VIC STARTUP";
const termsnConditions = 'By signing up you accept the Terms and Conditions.';
const successMsg = 'Your account has been created Successfully';
const cont = 'Continue';
const bool automaticallyImplyLeading = false;
const double bottomOpacityOne = 1.0;
const double tileSpacingOne = 1.0;
const double toolbarOpacityOne = 1.0;
const double elevationFive = 5.0;
const double expandedHeight = 1.0;
Widget flexibleSpaceBar = Text("");
const bool forceElevated = false;
Brightness brightness = Brightness.light;
const bool floating = false;
const bool pinned = false;
const bool snap = false;
const bool stretch = false;
const double selectedFontSize = 5.0;
const double unselectedFontSize = 5.0;
const int speedThousand = 1000;
const double opacity = 0.2;
const double opacityCard = 0.8;
const bool showselectedlabels = true;
const bool showUnselectedLabels = true;
const int maxLines = 3;
List<Widget> action = [
  IconButton(
    icon: Icon(Icons.arrow_back),
    onPressed: () {},
  )
];
List<BottomNavigationBarItem> item = [
  BottomNavigationBarItem(
    icon: Icon(Icons.home),
    label: 'Home',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.business),
    label: 'Business',
  ),
  BottomNavigationBarItem(
    icon: Icon(Icons.school),
    label: 'School',
  ),
];
const double stretchTriggerOffset = 1.0;

const IconData IconButton1 = Icons.add_box;
const IconData cameraIcon = Icons.camera_alt;

//VerticalTabs
const int durationTwo = 2;
const int snackbarDuration = 5000;
const double elevationTwo = 2.0;
const double tweenValueBegin = 0.0;
const double tweenValueEnd = 1.0;

const actPicjpg = 'images/account_picture.jpg';

const scanImage = "Scan";
const cameraPermissionDenied = "Camera permission was denied";
const cameraBackPress = "You pressed the back button before scanning anything";

//container dimensions
const containerwidth = 150.0;
const containerheight = 100.0;
const maxwidth = 600.0;

//Other constants

const jpg = '.jpg';
const jpeg = '.jpeg';
const png = '.png';

List<charts.Color> circleColors = [
  charts.MaterialPalette.red.shadeDefault,
  charts.MaterialPalette.blue.shadeDefault,
  charts.MaterialPalette.green.shadeDefault,
  charts.MaterialPalette.indigo.shadeDefault,
  charts.MaterialPalette.deepOrange.shadeDefault,
  charts.MaterialPalette.purple.shadeDefault,
  charts.MaterialPalette.yellow.shadeDefault,
  charts.MaterialPalette.gray.shadeDefault,
  charts.MaterialPalette.cyan.shadeDefault,
  charts.MaterialPalette.lime.shadeDefault,
  charts.MaterialPalette.pink.shadeDefault,
  charts.MaterialPalette.teal.shadeDefault,
  charts.MaterialPalette.red.shadeDefault,
  charts.MaterialPalette.blue.shadeDefault,
  charts.MaterialPalette.green.shadeDefault,
  charts.MaterialPalette.indigo.shadeDefault,
  charts.MaterialPalette.deepOrange.shadeDefault,
  charts.MaterialPalette.purple.shadeDefault,
  charts.MaterialPalette.yellow.shadeDefault,
  charts.MaterialPalette.gray.shadeDefault,
  charts.MaterialPalette.cyan.shadeDefault,
  charts.MaterialPalette.lime.shadeDefault,
  charts.MaterialPalette.pink.shadeDefault,
  charts.MaterialPalette.teal.shadeDefault,
  charts.MaterialPalette.purple.shadeDefault,
  charts.MaterialPalette.yellow.shadeDefault,
  charts.MaterialPalette.gray.shadeDefault,
  charts.MaterialPalette.cyan.shadeDefault,
  charts.MaterialPalette.lime.shadeDefault,
  charts.MaterialPalette.pink.shadeDefault,
  charts.MaterialPalette.teal.shadeDefault,
  charts.MaterialPalette.red.shadeDefault,
  charts.MaterialPalette.blue.shadeDefault,
  charts.MaterialPalette.cyan.shadeDefault,
  charts.MaterialPalette.lime.shadeDefault,
  charts.MaterialPalette.pink.shadeDefault,
  charts.MaterialPalette.teal.shadeDefault,
  charts.MaterialPalette.purple.shadeDefault,
  charts.MaterialPalette.yellow.shadeDefault,
  charts.MaterialPalette.gray.shadeDefault,
  charts.MaterialPalette.gray.shadeDefault,
  charts.MaterialPalette.cyan.shadeDefault,
  charts.MaterialPalette.lime.shadeDefault,
  charts.MaterialPalette.pink.shadeDefault,
  charts.MaterialPalette.teal.shadeDefault,
  charts.MaterialPalette.purple.shadeDefault,
  charts.MaterialPalette.yellow.shadeDefault,
  charts.MaterialPalette.gray.shadeDefault,
];
